@@ -22,7 +22,7 @@
 *	You should have received a copy of the GNU General Public License
 *	along with SCAMP. If not, see <http://www.gnu.org/licenses/>.
 *
-*	Last modified:		27/04/2020
+*	Last modified:		01/12/2020
 *
 *%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
@@ -194,6 +194,13 @@ astrefstruct	astrefcats[] =
 	{"G", "BP", "RP", ""},
 	3, 0},
 
+  {"GAIA-EDR3", "I/350/gaiaedr3", {"Dup", "RA_ICRS","DE_ICRS","e_RA_ICRS","e_DE_ICRS",
+		"Epoch","pmRA","pmDE","e_pmRA","e_pmDE",
+		"Gmag","e_Gmag","BPmag","e_BPmag","RPmag","e_RPmag",""},
+	{"Gmag", "BPmag","RPmag",""},
+	{"G", "BP", "RP", ""},
+	3, 0},
+
   {"PANSTARRS-1", "II/349", {"Qual", "RAJ2000","DEJ2000","e_RAJ2000","e_DEJ2000",
 		"Epoch", "gmag","e_gmag","rmag","e_rmag","imag","e_imag",
 		"zmag","e_zmag","ymag","e_ymag",""},
@@ -227,7 +234,7 @@ INPUT   Catalog name,
 OUTPUT  Pointer to the reference field.
 NOTES   Global preferences are used.
 AUTHOR  E. Bertin (IAP)
-VERSION	02/05/2018
+VERSION	01/12/2020
 */
 fieldstruct	*get_astreffield(astrefenum refcat, double *wcspos,
 				int lng, int lat, int naxis, double maxradius)
@@ -802,6 +809,7 @@ fieldstruct	*get_astreffield(astrefenum refcat, double *wcspos,
           break;
 
         case ASTREFCAT_GAIADR2:
+        case ASTREFCAT_GAIAEDR3:
 /*-------- Reject duplicated sources */
           sflag = cols[cindex++];
 /*
@@ -1240,7 +1248,7 @@ OUTPUT  setstruct pointer (allocated if the input setstruct pointer is NULL).
 NOTES   The filename is used for error messages only. Global preferences are
 	used.
 AUTHOR  E. Bertin (IAP)
-VERSION 27/04/2020
+VERSION 28/06/2020
 */
 setstruct *read_astrefsamples(setstruct *set, tabstruct *tab, char *rfilename,
 				double *wcspos, int lng, int lat, int naxis,
@@ -1253,13 +1261,14 @@ setstruct *read_astrefsamples(setstruct *set, tabstruct *tab, char *rfilename,
    samplestruct		*sample;
    char			str[MAXCHAR];
    char			*buf;
-   unsigned short	*flags;
+   unsigned short	*flags,
+			objflags;
    float		*xm,*ym, *xpm,*ypm, *xpmerr,*ypmerr,
 			*mag, *magerr, *obsdate, *erra,*errb;
    double		*dxm, *dym, *dxpm,*dypm, *dxpmerr,*dypmerr,
 			*dmag, *dmagerr, *dobsdate, *derra, *derrb,
 			x,y, dx,dy,dfac, ea,eb, maxradius2, mmag;
-   int			n, nsample,nsamplemax, nobj, objflags, maglimflag;
+   int			n, nsample,nsamplemax, nobj, maglimflag;
 
 /* One needs 2 angular coordinates here! */
   dxm = dym = dxpm = dypm = dxpmerr = dypmerr = dmag = derra = derrb \
