@@ -7,7 +7,7 @@
 *
 *	This file part of:	SCAMP
 *
-*	Copyright:		(C) 2002-2014 Emmanuel Bertin -- IAP/CNRS/UPMC
+*	Copyright:		(C) 2002-2018 IAP/CNRS/UPMC
 *
 *	License:		GNU General Public License
 *
@@ -22,14 +22,16 @@
 *	You should have received a copy of the GNU General Public License
 *	along with SCAMP. If not, see <http://www.gnu.org/licenses/>.
 *
-*	Last modified:		09/07/2014
+*	Last modified:		03/05/2018
 *
 *%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
+#ifndef _DEFINE_H_
+#define _DEFINE_H_
 /* Check if we are using a configure script here */
 #ifndef HAVE_CONFIG_H
-#define         VERSION         "1.x"
-#define         DATE            "2005-12-16"
+#define         VERSION         "2.x"
+#define         DATE            "03-05-18"
 #define		THREADS_NMAX	1024              /* max. number of threads */
 #endif
 
@@ -37,11 +39,11 @@
 
 #define         BANNER		"SCAMP"
 #define         MYVERSION       VERSION
-#define         COPYRIGHT       "2010-2013 IAP/CNRS/UPMC"
+#define         COPYRIGHT       "2010-2018 Sorbonne Université/Université de Bordeaux/CNRS"
 #define		DISCLAIMER	BANNER " comes with ABSOLUTELY NO WARRANTY\n" \
 		"You may redistribute copies of " BANNER "\n" \
 		"under the terms of the GNU General Public License."
-#define		AUTHORS		"Emmanuel BERTIN <bertin@iap.fr>"
+#define		AUTHORS		"Emmanuel BERTIN <bertin@iap.fr> and Sébastien Serre <serre@u-bordeaux.fr>"
 #define		WEBSITE		"http://astromatic.net/software/scamp"
 #define         INSTITUTE	"IAP  http://www.iap.fr"
 
@@ -57,7 +59,7 @@
 #define		TINY		(1.0/BIG)	/* a small number */
 #define		OUTPUT		stderr		/* where all msgs are sent */
 #define		MAXCHAR		512		/* max. number of characters */
-#define		MAXFILE		32768		/* max number of input files */
+#define		MAXFILE		100000		/* max number of input files */
 
 /*------------ Set defines according to machine's specificities -------------*/
 
@@ -177,3 +179,4 @@
 			else if (prefs.verbose_type == LOG) \
 				fprintf(w, "%s\n", x);}
 
+#endif // _DEFINE_H_
